<?php
require_once 'zinc/zinclib/device.inc';
require_once 'zinc/conf/cdplayer.conf';

class CDPlayer extends ZincDevice
{
    // System handling

    public static function isPlayerPresent()
    {
        return true;
    }

    public static function isDiscPresent()
    {
        if (self::isDrawerOpen()) {
           return false;
        }
        return true;
    }

    // Querying the state

    public static function getTrackCount()
    {
        if (!self::isDiscPresent()) {
           return 0;
        }
        $result = self::cmd("count");
        return (int)$result['output'];
    }

    public static function getCurrentTrack()
    {
        if (!self::isDiscPresent()) {
           return 0;
        }
        $result = self::cmd("current");
        return (int)$result['output'];
    }

    public static function getDiscName() 
    {
        if (!self::isDiscPresent()) {
           return "";
        }
        $result = self::cmd("discname");
        return $result['output'];
    }

    public static function getTrackName($track) 
    {
        if (!self::isDiscPresent()) {
           return "";
        }

        $result = self::cmd("trackname $track");
        return $result['output'];
    }

    public static function getTrackTick($track)
    {
        return NULL;
    }

    public static function isPlaying()
    {
        if (!self::isDiscPresent()) {
           return 0;
        }
        $result = self::cmd("isplaying");
        return (int)$result['output'];
    }

    public static function isStopped()
    {
        if (!self::isDiscPresent()) {
           return 0;
        }
        $result = self::cmd("isstopped");
        return (int)$result['output'];
    }

    public static function isPaused()
    {
        if (!self::isDiscPresent()) {
           return 0;
        }
        $result = self::cmd("ispaused");
        return (int)$result['output'];
    }

    public static function isDrawerOpen()
    {
        $result = self::cmd("isdraweropen");
        return (int)$result['output'];
    }

    public static function getTrackListing()
    {
        if (!self::isDiscPresent()) {
           return 0;
        }

        $trackList = array();
        $bypassnames = false;
        $count = self::getTrackCount();
        for($i=1;$i<=$count;++$i) {
           $name = $bypassnames ? "" : self::getTrackName($i);
           if ($name == "") {
              array_push($trackList, "Track $i\t");
              $bypassnames = true;
          } else {
              array_push($trackList, "$name\t");
          }
        }

        if ($trackList[count($trackList)-1] == "") {
           unset($trackList[count($trackList)-1]);
        }
        return $trackList;
    }
 
    protected static function cmd($cmd) 
    {
        $cmd = CDPlayerDevice::$binary." ".CDPlayerDevice::$device." ".$cmd;
        return parent::cmd($cmd);
    }

    // CD Control
    public static function playTrack($track) 
    {
         self::cmd("play $track");
    }
       
    public static function stopTrack() 
    {
         self::cmd("stop");
    }
       
    public static function pauseTrack() 
    {
         self::cmd("pause");
    }
       
    public static function resumeTrack() 
    {
        if (self::cmd("isstopped")==1) {
            return self::playTrack(self::getCurrentTrack());
        }
        self::cmd("resume");
    }
       
    public static function ejectDisc() 
    {
         self::cmd("eject");
    }
       
    public static function insertDisc() 
    {
         self::cmd("close");
    }
       
       
}

?>

